@@ -11,9 +11,11 @@ from termcolor import colored
 KEY = 'E0F0D336AF47D3797C68372A869BDBC5'
 URL = 'http://dict-co.iciba.com/api/dictionary.php'
 
+
 def get_response(word):
     return urllib2.urlopen(URL + '?key=' + KEY + '&w=' + word)
 
+
 def read_xml(xml):
     dom = minidom.parse(xml)
     return dom.documentElement
@@ -24,22 +26,20 @@ def show(node):
             tag_name = node.parentNode.tagName
             content = node.data.replace('\n', '')
             if tag_name == 'ps':
-                print colored(content, 'green')
-                print colored('------------------------------', 'green')
+                print colored('[' + content + ']', 'green')
             if tag_name == 'orig':
-                print colored(content, 'red')
+                print colored('ex. ' + content, 'blue')
             if tag_name == 'trans':
-                print colored(content, 'red')
-                print colored('------------------------------', 'red')
+                print colored('    ' + content, 'cyan')
             if tag_name == 'pos':
-                print colored(content, 'yellow')
+                print colored(content, 'green').ljust(12),
             if tag_name == 'acceptation':
                 print colored(content, 'yellow')
-                print colored('------------------------------', 'yellow')
     else:
         for e in node.childNodes:
             show(e)
 
+
 def main():
     try:
         options, args = getopt.getopt(sys.argv[1:], ["help"])
@@ -50,5 +50,6 @@ def main():
     root = read_xml(get_response(word))
     show(root)
 
+
 if __name__ == '__main__':
     main()
